#! /usr/bin/env python
# -*- coding: utf-8 -*-
'''
Created on 2022/5/22 17:32:21

@author: LiuKuan
@copyright: Apache License, Version 2.0
'''
import logging
import logging.handlers
import functools
#===============================================================================
'''     
'''
#===============================================================================
__all__ = [ 'get_logger',
            'log_add_rotate_file',
            'log_add_file',
            'log_add_console',
]

_def_fmt = '[%(asctime)s][%(levelname)s]%(message)s'
_logger_cache = {}

def log_add_rotate_file(filename=None, fmt = None, logger=None):
    if not logger:
        logger = get_logger()
    handler = logging.handlers.RotatingFileHandler(
        filename if filename else logger.name + ".log",
        maxBytes=1024 * 1024 * 1024 * 1,
        backupCount=5,
    )
    handler.setFormatter(logging.Formatter(fmt if fmt else _def_fmt))
    logger.addHandler(handler)
    return handler

def log_add_file(filename=None, fmt = None, logger=None):
    if not logger:
        logger = get_logger()
    handler = logging.FileHandler(filename if filename else logger.name + ".log")
    handler.setFormatter(logging.Formatter(fmt if fmt else _def_fmt))
    logger.addHandler(handler)
    return handler

def log_add_console(fmt = None, logger=None):
    if not logger:
        logger = get_logger()
    handler = logging.StreamHandler()
    handler.setFormatter(logging.Formatter(fmt if fmt else _def_fmt))
    logger.addHandler(handler)
    return handler

def _more_arg(func):
    @functools.wraps(func)
    def inner(*args, sep=' ', **kws):
        msg = sep.join(str(x) for x in args)
        return func(msg, **kws)
    return inner

def get_logger(name=None, level=logging.DEBUG):
    if name is None:
        name = "laok"

    if name in _logger_cache:
        return _logger_cache[name]

    log = logging.getLogger(name)
    _logger_cache[name] = log
    log.setLevel(level)
    log.debug = _more_arg(log.debug)
    log.info = _more_arg(log.info)
    log.warning = _more_arg(log.warning)
    log.error = _more_arg(log.error)
    log.critical = _more_arg(log.critical)
    return log



