#! /usr/bin/env python
# -*- coding: utf-8 -*-
'''
Created on 2022/10/18 02:35:56

@author: LiuKuan
@copyright: Apache License, Version 2.0
'''
import torch
from laok import size_to_str
# ===============================================================================
r'''
'''
# ===============================================================================
__all__ = ['print_tensor', 'print_model']


def print_tensor(data, title=None, show_data=True):
    '''print detail data information
    '''

    if title is None:
        msg = f"===="
    else:
        msg = f"====[{title}] "

    if isinstance(data, torch.Tensor):
        _type = 'Tensor'
    else:
        _type = type(data)

    msg += f'type[{_type}]'
    if isinstance(data, torch.Tensor):
        msg += f' shape{_fmt_size(data.shape)} dim[{data.ndim}] dtype[{_fmt_dtype(data.dtype)}] device[{data.device}]'

    msg += f' id[{id(data)}]\n'

    if show_data:
        msg += f'{data}'

    print(msg)
    return data

def print_model(model):
    print(f'=== name: {model.__class__.__name__}')
    for i, (name, param) in enumerate(model.named_parameters()):
        print( f"<{i}> {name}")
        print( f"    requires_grad:{param.requires_grad}  size={size_to_str(param.size())}")
    return model

def _fmt_size(sz):
    return '[' + ", ".join( str(i) for i in sz)  +']'

def _fmt_dtype(dt):
    return str(dt).replace('torch.', '')